use clap::{error::ErrorKind, CommandFactory};

use crate::logger::Level;


#[derive(Debug, clap::Parser)]
pub struct CliArgs {
    /// Output more info, will get overwritten if -q|--quiet is specified 
    #[arg(long, short)]
    verbose: bool,
    /// Output nothing, except errors, will overwrite -v|--verbose
    #[arg(long, short)]
    quiet: bool,
    /// Output file
    #[arg(long, short, default_value="a.out")]
    pub output: String,
    /// All input files
    #[clap(num_args = 1..)]
    pub input: Vec<String>
}

impl CliArgs {
    pub fn set_log_level(&self) {
        if self.quiet {
            unsafe {
                crate::logger::LEVEL = Level::Error;
            }
        } else if self.verbose {
            unsafe {
                crate::logger::LEVEL = Level::Debug;
            }
        }
    }
    pub fn validate(&self) {
        if self.input.len() < 1 {
            CliArgs::command().error(ErrorKind::TooFewValues, "at least one value is required for '<INPUT>' but none was supplied").exit();
        }
    }
}
