use std::{path::PathBuf, process::ExitCode};

use clap::Parser;
// Importing logger here too cause the logger macros dont work outside the mclanc lib
mod logger;




fn main() -> ExitCode {
    let cli = mclangc::cli::CliArgs::parse();
    cli.set_log_level();
    cli.validate();
    for file in &cli.input {
        let fp = PathBuf::from(file);
        if !fp.exists() {
            error!("File {fp:?} doesnt exits, exiting");
            return ExitCode::FAILURE;
        }

        let data = std::fs::read_to_string(fp).unwrap();
        info!("Tokenising {file}");
        let Ok(tokens) = mclangc::tokeniser::tokenise(&data, &file) else {
            error!("Failed to tokenise file, exiting");
            return ExitCode::FAILURE;
        };
        info!("Parsing {file}");
        let Ok(prog) = mclangc::parser::parse_program(tokens) else {
            error!("Failed to parse file, exiting");
            return ExitCode::FAILURE;
        };
        info!("Validating {file}");
        let Ok(validated) = mclangc::validator::validate_code(&prog) else {
            error!("Failed to validate file, exiting");
            return ExitCode::FAILURE;
        };
    }
    ExitCode::SUCCESS
}
