
use crate::common::Loc;

use super::{expr::{Block, ExprBox}, typ::{Type, TypeBox}, Ident, TString};

#[derive(Debug, Clone)]
pub struct StatementBox {
    inner: Statement,
    loc: Loc
}

impl StatementBox {
    pub fn new(loc: &Loc, stat: Statement) -> Self {
        Self { loc: loc.clone(), inner: stat }
    }
    pub fn inner(&self) -> &Statement {
        &self.inner
    }
    pub fn inner_mut(&mut self) -> &mut Statement {
        &mut self.inner
    }
    pub fn loc(&self) -> &Loc {
        &self.loc
    }
}

#[derive(Debug, Clone)]
pub enum Statement {
    Fn(Function),
    TypeAlias(TypeAlias),
    Struct(Struct),
    Enum(Enum),
    ConstVar {
        name: Ident,
        typ: TypeBox,
        val: ExprBox
    },
    StaticVar {
        name: Ident,
        typ: TypeBox,
        val: ExprBox,
    },
    Let {
        name: Ident,
        typ: Option<TypeBox>,
        val: Option<ExprBox>,
    },
}

#[derive(Debug, Clone)]
pub struct TypeAlias {
    pub name: Ident,
    pub typ: TypeBox,
}

#[derive(Debug, Clone)]
pub struct Struct {
    pub name: Ident,
    pub fields: Vec<(Ident, TypeBox)>,
}

#[derive(Debug, Clone)]
pub struct Enum {
    pub name: Ident,
    pub fields: Vec<Ident>,
}

#[derive(Debug, Clone)]
pub struct Function {
    pub struct_name: Option<Ident>,
    pub name: Ident,
    pub params: Vec<(Ident, TypeBox)>,
    pub ret_type: Option<TypeBox>,
    pub qual_const: bool,
    pub qual_extern: Option<TString>, // abi
    pub body: Option<Block>, // If None then its a type declaration
}
